@@ -1,3 +1,5 @@
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
 # For testing purposes we might need to set mpl backend before any
 # other import of matplotlib.
 def _set_mpl_backend():
@@ -14,12 +16,13 @@ _set_mpl_backend()
 # This is the only place the version is specified and 
 # used in both setup.py and docs/conf.py to set the 
 # version of ggplot.
-__version__ = '0.4.7'
+__version__ = '0.5.3'
 
-from .ggplot import *
+from .qplot import qplot
+from .ggplot import ggplot
 from .components import aes
 from .geoms import *
 from .scales import *
 from .themes import *
 from .utils import *
-from .exampledata import *
+from .exampledata import (diamonds,mtcars,meat,pageviews)
